@@ -57,7 +57,7 @@
 
 // sdh 28/6/2002: moved planes here
 
-static char swplnsym[ORIENTS][ANGLES][SYMBYTES] = {
+static unsigned char swplnsym[ORIENTS][ANGLES][SYMBYTES] = {
 
 /*  airplane symbols based on the following template file:
 16
@@ -372,7 +372,7 @@ static char swplnsym[ORIENTS][ANGLES][SYMBYTES] = {
     }
 };
 
-static char swhitsym[HITSYMS][SYMBYTES] = {  /*  Hit plane pixel array  */
+static unsigned char swhitsym[HITSYMS][SYMBYTES] = {  /*  Hit plane pixel array  */
 
 /*  airplane symbols based on the following template file:
 16
@@ -414,7 +414,7 @@ static char swhitsym[HITSYMS][SYMBYTES] = {  /*  Hit plane pixel array  */
 };
 
 
-static char swwinsym[WINSIZES][WINBYTES] = {  /*  Win plane pixel array  */
+static unsigned char swwinsym[WINSIZES][WINBYTES] = {  /*  Win plane pixel array  */
 
 /*  airplane symbols based on the following template files:
 16                                 16
@@ -492,7 +492,7 @@ static char swwinsym[WINSIZES][WINBYTES] = {  /*  Win plane pixel array  */
 };
 
 
-static char swbmbsym[BOMBANGS][BOMBBYTES] = {
+static unsigned char swbmbsym[BOMBANGS][BOMBBYTES] = {
 
 /*  bomb symbols based on the following template file:
 08
@@ -539,7 +539,7 @@ static char swbmbsym[BOMBANGS][BOMBBYTES] = {
 	}
 };
 
-static char swtrgsym[TARGORIENTS][TARGBYTES] = {
+static unsigned char swtrgsym[TARGORIENTS][TARGBYTES] = {
 
 /*  target symbols based on the following template files:
 16                                    16
@@ -617,7 +617,7 @@ static char swtrgsym[TARGORIENTS][TARGBYTES] = {
 	},
 };
 
-static char swhtrsym[TARGBYTES] = {
+static unsigned char swhtrsym[TARGBYTES] = {
 
 /*  hit target symbols based on the following template file:
 16
@@ -647,7 +647,7 @@ static char swhtrsym[TARGBYTES] = {
        0x55, 0xA5, 0x65, 0x55
 };
 
-static char swexpsym[EXPLSYMS][EXPBYTES] = {
+static unsigned char swexpsym[EXPLSYMS][EXPBYTES] = {
 
 /*  explosion symbols based on the following template files:
 08                 08                08                08
@@ -705,7 +705,7 @@ static char swexpsym[EXPLSYMS][EXPBYTES] = {
 	}
 };
 
-static char swflksym[FLCKSYMS][FLKBYTES] = {
+static unsigned char swflksym[FLCKSYMS][FLKBYTES] = {
 
 /*  flock symbols based on the following template files:
 16                                16
@@ -746,7 +746,7 @@ static char swflksym[FLCKSYMS][FLKBYTES] = {
 	},
 };
 
-static char swbrdsym[BIRDSYMS][BRDBYTES] = {
+static unsigned char swbrdsym[BIRDSYMS][BRDBYTES] = {
 
 /*  bird symbols based on the following template files:
 4         4
@@ -757,7 +757,7 @@ static char swbrdsym[BIRDSYMS][BRDBYTES] = {
        {0xCC, 0x30}
 };
 
-static char swoxsym[OXSYMS][OXBYTES] = {
+static unsigned char swoxsym[OXSYMS][OXBYTES] = {
 
 /*  ox symbols based on the following template files:
 16                                16
@@ -798,7 +798,7 @@ static char swoxsym[OXSYMS][OXBYTES] = {
 	},
 };
 
-static char swghtsym[GHSTBYTES] = {
+static unsigned char swghtsym[GHSTBYTES] = {
 
 /*  ghost symbol based on the following template file:
 08
@@ -815,7 +815,7 @@ static char swghtsym[GHSTBYTES] = {
        0x55, 0x55, 0x6A, 0xA9, 0x55, 0x55
 };
 
-static char swshtsym[SHOTBYTES] = {
+static unsigned char swshtsym[SHOTBYTES] = {
 
 /*  shot window symbol based on the following template file:
 16
@@ -845,7 +845,7 @@ static char swshtsym[SHOTBYTES] = {
        0x0 , 0x14, 0x0 , 0x10
 };
 
-static char swsplsym[SPLTBYTES] = {
+static unsigned char swsplsym[SPLTBYTES] = {
 
 /*  splatted bird symbol based on the following template file:
 32
@@ -910,7 +910,7 @@ static char swsplsym[SPLTBYTES] = {
        0x0 , 0x2 , 0x0 , 0x0 , 0x40, 0x20
 };
 
-static char swmscsym[MISCANGS][MISCBYTES] = {
+static unsigned char swmscsym[MISCANGS][MISCBYTES] = {
 
 /*  bomb symbols based on the following template file:
 
@@ -991,7 +991,7 @@ static char swmscsym[MISCANGS][MISCBYTES] = {
 	}
 };
 
-static char swbstsym[BRSTSYMS][BRSTBYTES] = {
+static unsigned char swbstsym[BRSTSYMS][BRSTBYTES] = {
 
 
 /*  starburst symbols based on the following template file:
@@ -1071,9 +1071,9 @@ sopsym_t *symbol_plane_win[4];            // swwinsym
 // special symbol for single pixel (bullets etc)
 
 sopsym_t symbol_pixel = {
-	data: NULL,
-	w: 1,
-	h: 1
+	.data = NULL,
+	.w = 1,
+	.h = 1
 };
 
 // generate symbols from data
@@ -1105,7 +1105,7 @@ void symbol_generate()
 	symbol_birdsplat = sopsym_from_data(swsplsym, 32, 32);
 
 	{
-		static char p = 3;
+		static unsigned char p = 3;
 		symbol_pixel.data = &p;
 	}
 }
